const {
  ApiAreaTree, ApiSaveAddr, ApiAddrDt, ApiAddrUpdate
} = require("../../http/api")
const {
  wxGet, wxPost, wxPut
} = require("../../http/network")
const { showToast } = require("../../utils/common")

// pages/address/add-address.js
Page({

  /**
   * 页面的初始数据
   */
  data: {
    id: 0,
    visible: false,
    cityList: [],
    countyList: [],
    streetList: [],
    cityName: "",
    countyName: "",
    streetName: "",
    currentPos: 0,
    namePath: "",
    areaId: 0
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {
    let id = options.id 
    if(id){
      wx.setNavigationBarTitle({
        title: '修改地址',
      })
      this.setData({
        id
      })
      this.getData()
    }
    this.getArea()
  },
  getData(){
    wxGet(ApiAddrDt + this.data.id).then(res=>{
      this.setData({
        address: res.data.address,
        areaId: res.data.areaId,
        name: res.data.name,
        namePath: res.data.namePath,
        phone: res.data.phone
      })
    })
  },
  getArea() {
    wxGet(ApiAreaTree).then(res => {
      this.setData({
        cityList: res.data
      })
    })
  },
  chooseAddress() {
    this.setData({
      visible: true
    })
  },
  dismissAction() {
    this.setData({
      visible: false
    })
  },
  chooseCity(e){
    let index = e.currentTarget.dataset.index
    this.setData({
      cityName: this.data.cityList[index].name,
      countyList: this.data.cityList[index].children,
      currentPos: 1
    })
  },
  chooseCounty(e){
    let index = e.currentTarget.dataset.index
    this.setData({
      countyName: this.data.countyList[index].name,
      streetList: this.data.countyList[index].children,
      currentPos: 2
    })
  },
  chooseStreet(e){
    let index = e.currentTarget.dataset.index
    this.setData({
      streetName: this.data.streetList[index].name,
      visible: false,
      areaId: this.data.streetList[index].id
    })
    this.setData({
      namePath: this.data.cityName + this.data.countyName + this.data.streetName
    })
  },
  changeCity(){
    this.setData({
      currentPos: 0
    })
  },
  changeCounty(){
    if(this.data.cityName.length == 0){
      showToast("请先选择市")
      return
    }
    this.setData({
      currentPos: 1
    })
  },
  changeStreet(){
    if(this.data.countyName.length == 0){
      showToast("请先选择区/县")
      return
    }
    this.setData({
      currentPos: 2
    })
  },
  saveAction(){
    if(this.data.name.length == 0){
      showToast("请输入姓名")
      return
    }
    if(this.data.phone.length == 0){
      showToast("请输入手机号")
      return
    }
    if(this.data.namePath.length == 0){
      showToast("请选择地址")
      return
    }
    if(this.data.address.length == 0){
      showToast("请输入详细地址")
      return
    }
    if(this.data.id > 0){
      wxPut(ApiAddrUpdate,{
        "address": this.data.address,
        "areaId": this.data.areaId,
        "name": this.data.name,
        "namePath": this.data.namePath,
        "phone": this.data.phone,
        "id": this.data.id
      }).then(res=>{
        wx.showToast({
          icon: 'none',
          title: '保存成功',
          complete:function(){
            wx.navigateBack()
          }
        })
      })
    }else{
      wxPost(ApiSaveAddr,{
        "address": this.data.address,
        "areaId": this.data.areaId,
        "name": this.data.name,
        "namePath": this.data.namePath,
        "phone": this.data.phone
      }).then(res=>{
        wx.showToast({
          icon: 'none',
          title: '保存成功',
          complete:function(){
            wx.navigateBack()
          }
        })
      })
    }
    
  }
})